//
//  NoteListView.swift
//  SlipboxProject
//
//  Created by Karin Prater on 29.11.22.
//

import SwiftUI
import CoreData

struct NoteListView: View {
    
    @ObservedObject var selectedFolder: Folder
    @Binding var selectedNote: Note?
    @Environment(\.managedObjectContext) private var viewContext
    
    var body: some View {
        List(selection: $selectedNote) {
            ForEach(selectedFolder.notes.sorted()) { note in
                NavigationLink(value: note) {
                    NoteRow(note: note)
                }
            }
            .onDelete(perform: deleteItems)
        }
        .toolbar {
            ToolbarItem {
                Button(action: addNote) {
                    Label("Add Item", systemImage: "note.text.badge.plus")
                }
            }
        }
    }
    
    private func addNote() {
        let newNote = Note(title: "new Note", context: viewContext)
        newNote.folder = selectedFolder
        selectedNote = newNote
    }
    
    private func deleteItems(offsets: IndexSet) {
        offsets.map { selectedFolder.notes.sorted()[$0] }.forEach(Note.delete(note:))
    }
}




struct NoteListView_Previews: PreviewProvider {
    static var previews: some View {
        
        let context = PersistenceController.preview.container.viewContext
        let folder = Folder(name: "new", context: context)
        
        return NoteListView(selectedFolder: folder,
                            selectedNote: .constant(nil))
            .environment(\.managedObjectContext, context)
    }
}
