//
//  NotePhotoSelectorButton.swift
//  SlipboxProject
//
//  Created by Karin Prater on 24.11.22.
//

import SwiftUI
import PhotosUI

struct NotePhotoSelectorButton: View {
    
    @Environment(\.managedObjectContext) var context
   @ObservedObject var note: Note
    @State private var selectedItem: PhotosPickerItem? = nil
    
    var body: some View {
        
        PhotosPicker(selection: $selectedItem,
                     matching: .images,
                     photoLibrary: .shared()) {
            if note.attachment == nil {
                Text("import a photo")
            } else {
                Text("change photo")
            }
        }
        
       .onChange(of: selectedItem) { newValue in
                         Task {
                             do {
                                 if let data = try await newValue?.loadTransferable(type: Data.self) {
                                     update(data: data)
                                 }
                             } catch {
                                 print("Photopicker error: \(error.localizedDescription)")
                             }
                         }
                     }
    }
    
    @MainActor
    func update(data: Data) {
        if let attachment = note.attachment {
            attachment.fullImageData = data
            attachment.thumbnailData = nil
        } else {
            note.attachment = Attachment(image: data, context: context)
        }
    }
}

struct NotePhotoSelectorButton_Previews: PreviewProvider {
    static var previews: some View {
        NotePhotoSelectorButton(note: Note(title: "new", context: PersistenceController.preview.container.viewContext))
    }
}
