//
//  NotesFolderRelationshipTests.swift
//  SlipboxProjectTests
//
//  Created by Karin Prater on 29.11.22.
//

import XCTest
@testable import SlipboxProject
import CoreData

final class NotesFolderRelationshipTests: XCTestCase {

    var controller: PersistenceController!
    
    var context: NSManagedObjectContext {
        controller.container.viewContext
    }

    override func setUpWithError() throws {
        self.controller = PersistenceController.createEmpty()
    }

    override func tearDownWithError() throws {
        self.controller = nil
    }


    func test_add_note_to_folder() {
        
        let note = Note(title: "new note", context: context)
        let folder = Folder(name: "new folder", context: context)
        
      //  folder.notes.insert(note)
      //  XCTAssertTrue(note.folder == folder)
        
        note.folder = folder
        XCTAssertTrue(folder.notes.contains(note))
    }
    
    func test_delete_note_in_folder() {
        // delete rule nullify
        
        let note = Note(title: "new note", context: context)
        let folder = Folder(name: "new folder", context: context)
        note.folder = folder
        
        Note.delete(note: note)
      
        let retrievedNotes = try! context.fetch(Note.fetch(.all))
        
        XCTAssertFalse(folder.notes.contains(note))
        XCTAssertTrue(folder.notes.count == 0)
        XCTAssertTrue(retrievedNotes.count == 0)
    }
    
    func test_delete_folder_with_notes() {
        // delete rule: cascading
        
        let note = Note(title: "new note", context: context)
        let folder = Folder(name: "new folder", context: context)
        note.folder = folder
        
        Folder.delete(folder)
        
        let retrievedFolders = try! context.fetch(Folder.fetch(.all))
        let retrievedNotes = try! context.fetch(Note.fetch(.all))
        
        XCTAssertTrue(retrievedFolders.count == 0, "should have deleted the one folder")
        XCTAssertTrue(retrievedNotes.count == 0)
        
    }
}
